==> haskell-hsopenssl-x509-system-0.1.0.4-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-6OUtrRX3LkgHmxC5jc6iIZ
key:                  HsOpenSSL-x509-system-0.1.0.4-6OUtrRX3LkgHmxC5jc6iIZ
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  491c54925a1f5b28fbd4aca2f2ec60a8
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-6OUtrRX3LkgHmxC5jc6iIZ
depends:
    HsOpenSSL-0.11.7.9-7GHIB2Mkk3dAUqn8ip9pbx base-4.17.2.1
    bytestring-0.11.5.3 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-x509-system-0.1.0.4-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-HE4HqhWa49o3JeEm0rhkyV
key:                  HsOpenSSL-x509-system-0.1.0.4-HE4HqhWa49o3JeEm0rhkyV
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  c8dcf4d8b91b8853a396c5553619a1f6
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-HE4HqhWa49o3JeEm0rhkyV
depends:
    HsOpenSSL-0.11.7.9-po2iCNtLSz6kHoT9dMqPK base-4.17.2.1
    bytestring-0.11.5.3 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
